@@ -1,10 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "express" "0.6.0"
+(define-package "express" "20260202.1155"
   "Alternatives to `message'."
-  '((string-utils "0.3.2"))
+  '((emacs        "24.3")
+    (string-utils "0.3.2"))
   :url "http://github.com/rolandwalker/express"
-  :commit "e6dc9abdc395ef537408befebeb4fd3ed4ee5c60"
-  :revdesc "v0.6.0-0-ge6dc9abdc395"
+  :commit "f98932f43771eea3cadd36002670d2099a0258f8"
+  :revdesc "f98932f43771"
   :keywords '("extensions" "message" "interface")
   :authors '(("Roland Walker" . "walker@pobox.com"))
   :maintainers '(("Roland Walker" . "walker@pobox.com")))
